@@ -132,12 +132,13 @@ class System(pc.System):
             #we need to estimate a rough idea
             needed_atoms = 200 - len(atoms)
             #get a rough cell
-            needed_cells = needed_atoms/2
+            needed_cells = np.ceil(needed_atoms/len(atoms))
             nx = int(needed_cells**(1/3))
+            nx = int(np.ceil(nx/2))
 
             if np.sum(self.box) == 0:
                 raise ValueError("Simulation box should be initialized before atoms")
-            atoms = self.repeat((nx+1, nx+1, nx+1), atoms=atoms, ghost=True, scale_box=True)
+            atoms = self.repeat((nx, nx, nx), atoms=atoms, ghost=True, scale_box=True)
 
         self.set_atoms(atoms)
 
@@ -523,9 +524,19 @@ class System(pc.System):
                 raise RuntimeError("Could not find enough neighbors - try increasing threshold")
 
         elif method == 'voronoi':
+            
             self.voroexp = int(voroexp)
+
+            #copy the simulation cell
+            backupbox = self._box.copy()
+            if self.triclinic:
+                self.embed_in_cubic_box()
+            #self.embed_in_cubic_box()
             self.get_all_neighbors_voronoi()
 
+            #replace box
+            self.box = backupbox
+
         self.neighbors_found = True
 
     def find_diamond_neighbors(self):
@@ -1286,7 +1297,7 @@ class System(pc.System):
 
         return st
 
-    def calculate_centrosymmetry(self, nmax=12, calculate_neighbors=True, algorithm="ges"):
+    def calculate_centrosymmetry(self, nmax=12, get_vals=True):
         """
         Calculate the centrosymmetry parameter
 
@@ -1296,23 +1307,9 @@ class System(pc.System):
             number of neighbors to be considered for centrosymmetry 
             parameters. Has to be a positive, even integer. Default 12
 
-        calculate_neighbors : bool, optional
-            if True recalculate neighbors using number method, if False
-            neighbor calculation is not done. 
-
-        algorithm : {'ges', 'gvm'}, optional
-            `ges` uses the Greedy Edge Selection algorithm,
-            `gvm` uses Greedy Vertex Matching. Default `ges`.
-
         Returns
         -------
         None
-
-        References
-        ----------
-        .. [1] Stukowski, A, Model Simul Mater SC 20, 2012
-        .. [2] Bulatov, Cai, ISBN:978-0198526148, 2006
-        .. [3] Larsen, arXiv:2003.08879v1, 2020
         
         Notes
         -----
@@ -1321,14 +1318,14 @@ class System(pc.System):
         symmetry of an atomic environment. Centrosymmetry recalculates the neighbor using
         the number method as specified in :func:`¬pyscal.core.System.find_neighbors` method. This
         is the ensure that the required number of neighbors are found for calculation of the parameter.
-        The calculation of neighbors through number method can be suppressed by setting
-        ``calculate_neighbors=False``.
 
-        This method uses two different algorithms, The Greedy Edge Selection (GES) [1] or the
-        Greedy Vertex Matching (GVM) [2] as specified in [3]. GES algorithm is implemented
-        in LAMMPS and Ovito, whereas GVM is used in AtomEye and Atomsk. Please see [3] for
-        a detailed description of the algorithms. The algorithm can be selected using the
-        `algorithm` argument. GVM values are not normalised currently.
+        The Greedy Edge Selection (GES) [1] as specified in [2] in used in this method. 
+        GES algorithm is implemented in LAMMPS and Ovito. Please see [2] for
+        a detailed description of the algorithms. 
+        References
+        ----------
+        .. [1] Stukowski, A, Model Simul Mater SC 20, 2012
+        .. [2] Larsen, arXiv:2003.08879v1, 2020
 
         """
         if not nmax>0:
@@ -1337,123 +1334,11 @@ class System(pc.System):
         if not nmax%2 == 0:
             raise ValueError("nmax has to even integer")
 
-        if calculate_neighbors:
-            self.find_neighbors(method="number", nmax=nmax)
+        self.ccalculate_centrosymmetry(nmax)
 
-        if algorithm == "ges":
-            self.greedy_edge_selection(nmax)
-        elif algorithm == "gvm":
-            self.greedy_vertex_matching(nmax)
-        else:
-            raise ValueError("unknown algorithm")
-
-
-    def greedy_edge_selection(self, nmax):
-        """
-        Greedy edge selection scheme for centrosymmetry parameters
-
-        Parameters
-        ----------
-        nmax : int
-            number of neighbors to be considered for centrosymmetry 
-            parameters
-
-        Returns
-        -------
-        None
-
-        References
-        ----------
-        .. [1] Stukowski, A, Model Simul Mater SC 20, 2012
-
-        """
-        atoms = self.atoms
-        for atom in atoms:
-            distvectors = atom.neighbor_vector
-
-            #go through all combinations
-            combos = list(itertools.combinations(range(atom.coordination), 2))
-            selected_combos = []
-
-            data = []
-
-            for c, combo in enumerate(combos):
-                distsum = np.array(distvectors[combo[0]]) + np.array(distvectors[combo[1]])
-                distsum = np.sum([x**2 for x in distsum])
-                weight = np.sqrt(distsum)
-                dd = [combo, distsum, weight, c]
-                data.append(dd)
-                
-            #now sort weights
-            data = np.array(data)
-            sorted_data = data[np.argsort(data[:,2])]
-
-            csym = 0
-            for i in range(nmax//2):
-                csym += sorted_data[i][1]
-                selected_combos.append(sorted_data[i][0])
-
-            atom.centrosymmetry = csym
-
-        self.atoms = atoms
-
-
-    def greedy_vertex_matching(self, nmax):
-        """
-        Greedy vertex matching scheme for centrosymmetry parameters
-
-        Parameters
-        ----------
-        nmax : int
-            number of neighbors to be considered for centrosymmetry 
-            parameters
-
-        Returns
-        -------
-        None
-
-        References
-        ----------
-        .. [1] Bulatov, Cai, ISBN:978-0198526148, 2006
-        
-        """
-        atoms = self.atoms
-        for atom in atoms:
-            distvectors = atom.neighbor_vector
-            distances = atom.neighbor_distance
-            sorted_distance_args = np.argsort(distances)
-            neighs = atom.neighbors
-            scombos = []
-
-            combos = list(itertools.combinations(range(atom.coordination), 2))
-            combos = np.array(combos)
-
-            data = []
-
-            for c, combo in enumerate(combos):
-                distsum = np.array(distvectors[combo[0]]) + np.array(distvectors[combo[1]])
-                distsum = np.sum([x**2 for x in distsum])
-                weight = np.sqrt(distsum)
-                dd = [combo, distsum, weight, c]
-                data.append(dd)
-
-            data = np.array(data)
-            csym = 0
-            for ind in sorted_distance_args:
-                ndata = data[combos[:,0]==ind]
-                if len(ndata) > 0:
-                    spair = ndata[np.argsort(ndata[:,2])][0]
-                    csym += spair[1]
-                    scombos.append(spair[0])
-                    i1, i2 = spair[0]
-                    arr = (combos[:,0]!=i1)*(combos[:,1]!=i1)*(combos[:,0]!=i2)*(combos[:,1]!=i2)
-                    combos = combos[arr]
-                    data = data[arr]
-                    if len(combos) == 0:
-                        break 
-            atom.centrosymmetry = csym
-
-        self.atoms = atoms
+        if get_vals:
+            vals = self.get_centrosymmetry()
+            return vals 
 
 
     def calculate_disorder(self, averaged=False, q=6):
@@ -1881,9 +1766,20 @@ class System(pc.System):
         newatoms = []
         idstart = len(atoms) + 1
 
-        for i in range(0, reps[0]):
-            for j in range(0, reps[1]):
-                for k in range(0, reps[2]):
+        x1 = -reps[0]
+        x2 = reps[0]+1
+        y1 = -reps[1]
+        y2 = reps[1]+1
+        z1 = -reps[2]
+        z2 = reps[2]+1
+        xs = 2*reps[0] + 1
+        ys = 2*reps[1] + 1
+        zs = 2*reps[2] + 1
+
+
+        for i in range(x1, x2):
+            for j in range(y1, y2):
+                for k in range(z1, z2):
                     if (i==j==k==0):
                         continue
                     for atom in atoms:
@@ -1899,9 +1795,9 @@ class System(pc.System):
                         newatoms.append(a)
 
         if scale_box:
-            box[0] = reps[0]*np.array(box[0])
-            box[1] = reps[1]*np.array(box[1])
-            box[2] = reps[2]*np.array(box[2])
+            box[0] = xs*np.array(box[0])
+            box[1] = ys*np.array(box[1])
+            box[2] = zs*np.array(box[2])
             self.box = box
         if ghost:
             self.ghosts_created = True
@@ -1911,6 +1807,58 @@ class System(pc.System):
         return completeatoms
 
 
+    def embed_in_cubic_box(self,):
+        """
+        Embedded the triclinic box in a cubic box
+        """
+        #first task is to create a box representation
+        
+        box = self._box
+        backupbox = box.copy()
+        
+        a = np.array(box[0])
+        b = np.array(box[1])
+        c = np.array(box[2])
+
+        cosa = np.dot(b, c)/(np.linalg.norm(b)*np.linalg.norm(c))
+        cosb = np.dot(c, a)/(np.linalg.norm(c)*np.linalg.norm(a))
+        cosc = np.dot(a, b)/(np.linalg.norm(a)*np.linalg.norm(b))
+
+        lx = np.linalg.norm(a)
+        xy = np.linalg.norm(b)*cosc
+        xz = np.linalg.norm(c)*cosb
+        ly = np.sqrt(np.linalg.norm(b)*np.linalg.norm(b) - xy*xy)
+        yz = (np.linalg.norm(b)*np.linalg.norm(c)*cosa - xy*xz)/ly
+        lz = np.sqrt(np.linalg.norm(c)*np.linalg.norm(c) - xz*xz - yz*yz)
+
+        xlo = ylo = zlo = 0
+        xhi = lx
+        yhi = ly
+        zhi = lz
+
+        xlo_bound = xlo + min(0.0,xy,xz,xy+xz)
+        xhi_bound = xhi + max(0.0,xy,xz,xy+xz)
+        ylo_bound = ylo + min(0.0,yz)
+        yhi_bound = yhi + max(0.0,yz)
+        zlo_bound = zlo
+        zhi_bound = zhi
+
+        newbox = np.array([[xhi_bound-xlo_bound, 0, 0], [0, yhi_bound-ylo_bound, 0], [0, 0, zhi_bound-zlo_bound]])
+        
+        #we also need to remap atoms
+        #atoms = self.get_all_atoms()
+        #for atom in atoms:
+        #    pos = atom.pos
+        #    pos[0] = pos[0]-xlo_bound
+        #    pos[1] = pos[1]-ylo_bound
+        #    pos[2] = pos[2]-zlo_bound
+        #    atom.pos = pos
+
+
+        self.newbox = newbox
+        self.box = newbox
+        #self.atoms = atoms
+
     def show(self, colorby=None, filterby=None):
         """
         Plot the system
